# Web Playground


A demo web application useful for sharpening automation tools. Written in Python and Flask.

Used by [Golem](https://github.com/golemhq/golem)

## Installing

Requires: Python 3.5+

```bash
pip install web-playground
```

## Start

```bash
web-playground [-p|--port]
```

Default port is 6565.

## License

[MIT](https://tldrlegal.com/license/mit-license)